@@ -9,12 +9,11 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+"""Formatters."""
+
 import logging
 
-try:
-    from pythonjsonlogger import jsonlogger
-except ImportError:
-    jsonlogger = None
+from pythonjsonlogger import jsonlogger
 
 
 DEFAULT_FORMAT = (
@@ -29,20 +28,21 @@ DEFAULT_EXTRAS_FORMAT = (
 
 
 class ColorFormatter(logging.Formatter):
-    """Colorizes log output"""
+    """Colorizes log output."""
 
     # TODO(jd) Allow configuration
     LEVEL_COLORS = {
-        logging.DEBUG: '\033[00;32m',  # GREEN
-        logging.INFO: '\033[00;36m',  # CYAN
-        logging.WARN: '\033[01;33m',  # BOLD YELLOW
-        logging.ERROR: '\033[01;31m',  # BOLD RED
-        logging.CRITICAL: '\033[01;31m',  # BOLD RED
+        logging.DEBUG: "\033[00;32m",  # GREEN
+        logging.INFO: "\033[00;36m",  # CYAN
+        logging.WARN: "\033[01;33m",  # BOLD YELLOW
+        logging.ERROR: "\033[01;31m",  # BOLD RED
+        logging.CRITICAL: "\033[01;31m",  # BOLD RED
     }
 
-    COLOR_STOP = '\033[0m'
+    COLOR_STOP = "\033[0m"
 
     def add_color(self, record):
+        """Add color to a record."""
         if getattr(record, "_stream_is_a_tty", False):
             record.color = self.LEVEL_COLORS[record.levelno]
             record.color_stop = self.COLOR_STOP
@@ -51,10 +51,12 @@ class ColorFormatter(logging.Formatter):
             record.color_stop = ""
 
     def remove_color(self, record):
+        """Remove color from a record."""
         del record.color
         del record.color_stop
 
     def format(self, record):
+        """Format a record."""
         self.add_color(record)
         s = super(ColorFormatter, self).format(record)
         self.remove_color(record)
@@ -66,10 +68,13 @@ class ExtrasFormatter(logging.Formatter):
 
     Any keywords passed to a logging call will be formatted into a
     "extras" string and included in a logging message.
+
     Example:
         logger.info('my message', extra='keyword')
+
     will cause an "extras" string of:
         [extra: keyword]
+
     to be inserted into the format in place of %(extras)s.
 
     The optional `keywords` argument must be passed into the init
@@ -80,28 +85,31 @@ class ExtrasFormatter(logging.Formatter):
     Special keywords:
 
     keywords
-      A set of strings containing keywords to filter out of the
-      "extras" string.
+        A set of strings containing keywords to filter out of the
+        "extras" string.
 
     extras_template
-      A format string to use instead of '[{0}: {1}]'
+        A format string to use instead of '[{0}: {1}]'
 
     extras_separator
-      What string to "join" multiple "extras" with.
+        What string to "join" multiple "extras" with.
 
     extras_prefix and extras_suffix
-      Strings which will be prepended and appended to the "extras"
-      string respectively. These will only be prepended if the
-      "extras" string is not empty.
+        Strings which will be prepended and appended to the "extras"
+        string respectively. These will only be prepended if the
+        "extras" string is not empty.
     """
 
-    def __init__(self,
-                 keywords=None,
-                 extras_template='[{0}: {1}]',
-                 extras_separator=' ',
-                 extras_prefix=' ',
-                 extras_suffix='',
-                 *args, **kwargs):
+    def __init__(
+        self,
+        keywords=None,
+        extras_template="[{0}: {1}]",
+        extras_separator=" ",
+        extras_prefix=" ",
+        extras_suffix="",
+        *args,
+        **kwargs
+    ):
         self.keywords = set() if keywords is None else keywords
         self.extras_template = extras_template
         self.extras_separator = extras_separator
@@ -110,16 +118,16 @@ class ExtrasFormatter(logging.Formatter):
         super(ExtrasFormatter, self).__init__(*args, **kwargs)
 
     def add_extras(self, record):
-        if not hasattr(record, '_daiquiri_extra_keys'):
-            record.extras = ''
+        if not hasattr(record, "_daiquiri_extra_keys"):
+            record.extras = ""
             return
 
         extras = self.extras_separator.join(
             self.extras_template.format(k, getattr(record, k))
             for k in record._daiquiri_extra_keys
-            if k != '_daiquiri_extra_keys' and k not in self.keywords
+            if k != "_daiquiri_extra_keys" and k not in self.keywords
         )
-        if extras != '':
+        if extras != "":
             extras = self.extras_prefix + extras + self.extras_suffix
         record.extras = extras
 
@@ -143,6 +151,26 @@ class ColorExtrasFormatter(ColorFormatter, ExtrasFormatter):
         return s
 
 
+class DatadogFormatter(jsonlogger.JsonFormatter):
+    def __init__(self):
+        super(DatadogFormatter, self).__init__(timestamp=True)
+
+    def add_fields(self, log_record, record, message_dict):
+        super(DatadogFormatter, self).add_fields(log_record, record, message_dict)
+        log_record["status"] = record.levelname.lower()
+        log_record["logger"] = {
+            "name": record.name,
+        }
+        if record.exc_info:
+            log_record["error"] = {
+                "kind": record.exc_info[0].__name__,
+                "stack": message_dict.get("stack_info"),
+                "message": message_dict.get("exc_info"),
+            }
+            log_record.pop("exc_info", None)
+            log_record.pop("stack_info", None)
+
+
 TEXT_FORMATTER = ColorExtrasFormatter(fmt=DEFAULT_EXTRAS_FORMAT)
-if jsonlogger:
-    JSON_FORMATTER = jsonlogger.JsonFormatter()
+JSON_FORMATTER = jsonlogger.JsonFormatter()
+DATADOG_FORMATTER = DatadogFormatter()
